Struct gdnative::export::IndexBounds

pub struct IndexBounds {
    pub start: Option<usize>,
    pub end: Option<usize>,
}
Defines which number of arguments is valid.

Convertible from an exact value a as well as inclusive range expressions a.., ..=b, a..=b.

Fields

start: Option<usize>

The lower (inclusive) bound of the expected number of arguments, or None if unbounded.

end: Option<usize>

The upper (inclusive) bound of the expected number of arguments, or None if unbounded.

Implementations



impl IndexBounds

pub fn contains(&self, value: usize) -> bool