Struct gdnative::CenterContainer [−][src]
pub struct CenterContainer { /* fields omitted */ }core class CenterContainer : Container (manually managed)
Base class
CenterContainer inherits Container and all of its methods.
Memory management
Non reference counted objects such as the ones of this type are usually owned by the engine.
In the cases where Rust code owns an object of this type, ownership should be either passed
to the engine or the object must be manually destroyed using CenterContainer::free.
Methods
impl CenterContainer[src]
impl CenterContainerpub fn as_container(&self) -> Container[src]
pub fn as_container(&self) -> ContainerUp-cast.
pub fn new() -> Self[src]
pub fn new() -> SelfConstructor.
Because this type is not reference counted, the lifetime of the returned object
is not automatically managed.
Immediately after creation, the object is owned by the caller, and can be
passed to the engine (in which case the engine will be responsible for
destroying the object) or destroyed manually using CenterContainer::free.
pub unsafe fn free(self)[src]
pub unsafe fn free(self)Manually deallocate the object.
pub fn set_use_top_left(&mut self, enable: bool)[src]
pub fn set_use_top_left(&mut self, enable: bool)pub fn is_using_top_left(&self) -> bool[src]
pub fn is_using_top_left(&self) -> boolpub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Methods from Deref<Target = Container>
pub fn as_control(&self) -> Control[src]
pub fn as_control(&self) -> ControlUp-cast.
pub fn _sort_children(&mut self)[src]
pub fn _sort_children(&mut self)pub fn _child_minsize_changed(&mut self)[src]
pub fn _child_minsize_changed(&mut self)pub fn queue_sort(&mut self)[src]
pub fn queue_sort(&mut self)pub fn fit_child_in_rect(&mut self, child: Option<Object>, rect: Rect2)[src]
pub fn fit_child_in_rect(&mut self, child: Option<Object>, rect: Rect2)pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Trait Implementations
impl GodotObject for CenterContainer[src]
impl GodotObject for CenterContainerfn class_name() -> &'static str[src]
fn class_name() -> &'static strunsafe fn from_sys(obj: *mut godot_object) -> Self[src]
unsafe fn from_sys(obj: *mut godot_object) -> Selfunsafe fn to_sys(&self) -> *mut godot_object[src]
unsafe fn to_sys(&self) -> *mut godot_objectimpl Deref for CenterContainer[src]
impl Deref for CenterContainertype Target = Container
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for CenterContainer[src]
impl DerefMut for CenterContainerAuto Trait Implementations
impl !Send for CenterContainer
impl !Send for CenterContainerimpl !Sync for CenterContainer
impl !Sync for CenterContainer