Struct gdnative::HingeJoint [−][src]
pub struct HingeJoint { /* fields omitted */ }core class HingeJoint : Joint (manually managed)
Base class
HingeJoint inherits Joint and all of its methods.
Memory management
Non reference counted objects such as the ones of this type are usually owned by the engine.
In the cases where Rust code owns an object of this type, ownership should be either passed
to the engine or the object must be manually destroyed using HingeJoint::free.
Methods
impl HingeJoint[src]
impl HingeJointpub fn as_joint(&self) -> Joint[src]
pub fn as_joint(&self) -> JointUp-cast.
pub fn new() -> Self[src]
pub fn new() -> SelfConstructor.
Because this type is not reference counted, the lifetime of the returned object
is not automatically managed.
Immediately after creation, the object is owned by the caller, and can be
passed to the engine (in which case the engine will be responsible for
destroying the object) or destroyed manually using HingeJoint::free.
pub unsafe fn free(self)[src]
pub unsafe fn free(self)Manually deallocate the object.
pub fn set_param(&mut self, param: i64, value: f64)[src]
pub fn set_param(&mut self, param: i64, value: f64)pub fn get_param(&self, param: i64) -> f64[src]
pub fn get_param(&self, param: i64) -> f64pub fn set_flag(&mut self, flag: i64, enabled: bool)[src]
pub fn set_flag(&mut self, flag: i64, enabled: bool)pub fn get_flag(&self, flag: i64) -> bool[src]
pub fn get_flag(&self, flag: i64) -> boolpub fn _set_upper_limit(&mut self, upper_limit: f64)[src]
pub fn _set_upper_limit(&mut self, upper_limit: f64)pub fn _get_upper_limit(&self) -> f64[src]
pub fn _get_upper_limit(&self) -> f64pub fn _set_lower_limit(&mut self, lower_limit: f64)[src]
pub fn _set_lower_limit(&mut self, lower_limit: f64)pub fn _get_lower_limit(&self) -> f64[src]
pub fn _get_lower_limit(&self) -> f64pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Methods from Deref<Target = Joint>
pub fn as_spatial(&self) -> Spatial[src]
pub fn as_spatial(&self) -> SpatialUp-cast.
pub fn set_node_a(&mut self, node: NodePath)[src]
pub fn set_node_a(&mut self, node: NodePath)pub fn get_node_a(&self) -> NodePath[src]
pub fn get_node_a(&self) -> NodePathpub fn set_node_b(&mut self, node: NodePath)[src]
pub fn set_node_b(&mut self, node: NodePath)pub fn get_node_b(&self) -> NodePath[src]
pub fn get_node_b(&self) -> NodePathpub fn set_solver_priority(&mut self, priority: i64)[src]
pub fn set_solver_priority(&mut self, priority: i64)pub fn get_solver_priority(&self) -> i64[src]
pub fn get_solver_priority(&self) -> i64pub fn set_exclude_nodes_from_collision(&mut self, enable: bool)[src]
pub fn set_exclude_nodes_from_collision(&mut self, enable: bool)pub fn get_exclude_nodes_from_collision(&self) -> bool[src]
pub fn get_exclude_nodes_from_collision(&self) -> boolpub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Trait Implementations
impl GodotObject for HingeJoint[src]
impl GodotObject for HingeJointfn class_name() -> &'static str[src]
fn class_name() -> &'static strunsafe fn from_sys(obj: *mut godot_object) -> Self[src]
unsafe fn from_sys(obj: *mut godot_object) -> Selfunsafe fn to_sys(&self) -> *mut godot_object[src]
unsafe fn to_sys(&self) -> *mut godot_objectimpl Deref for HingeJoint[src]
impl Deref for HingeJointtype Target = Joint
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for HingeJoint[src]
impl DerefMut for HingeJointAuto Trait Implementations
impl !Send for HingeJoint
impl !Send for HingeJointimpl !Sync for HingeJoint
impl !Sync for HingeJoint