Struct gdnative::LinkButton [−][src]
pub struct LinkButton { /* fields omitted */ }core class LinkButton : BaseButton (manually managed)
Base class
LinkButton inherits BaseButton and all of its methods.
Memory management
Non reference counted objects such as the ones of this type are usually owned by the engine.
In the cases where Rust code owns an object of this type, ownership should be either passed
to the engine or the object must be manually destroyed using LinkButton::free.
Methods
impl LinkButton[src]
impl LinkButtonUp-cast.
pub fn new() -> Self[src]
pub fn new() -> SelfConstructor.
Because this type is not reference counted, the lifetime of the returned object
is not automatically managed.
Immediately after creation, the object is owned by the caller, and can be
passed to the engine (in which case the engine will be responsible for
destroying the object) or destroyed manually using LinkButton::free.
pub unsafe fn free(self)[src]
pub unsafe fn free(self)Manually deallocate the object.
pub fn set_text(&mut self, text: GodotString)[src]
pub fn set_text(&mut self, text: GodotString)pub fn get_text(&self) -> GodotString[src]
pub fn get_text(&self) -> GodotStringpub fn set_underline_mode(&mut self, underline_mode: i64)[src]
pub fn set_underline_mode(&mut self, underline_mode: i64)pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Methods from Deref<Target = BaseButton>
pub fn as_control(&self) -> Control[src]
pub fn as_control(&self) -> ControlUp-cast.
pub fn _pressed(&mut self)[src]
pub fn _pressed(&mut self)pub fn _toggled(&mut self, button_pressed: bool)[src]
pub fn _toggled(&mut self, button_pressed: bool)pub fn _gui_input(&mut self, arg0: Option<InputEvent>)[src]
pub fn _gui_input(&mut self, arg0: Option<InputEvent>)pub fn _unhandled_input(&mut self, arg0: Option<InputEvent>)[src]
pub fn _unhandled_input(&mut self, arg0: Option<InputEvent>)pub fn set_pressed(&mut self, pressed: bool)[src]
pub fn set_pressed(&mut self, pressed: bool)pub fn is_pressed(&self) -> bool[src]
pub fn is_pressed(&self) -> boolpub fn is_hovered(&self) -> bool[src]
pub fn is_hovered(&self) -> boolpub fn set_toggle_mode(&mut self, enabled: bool)[src]
pub fn set_toggle_mode(&mut self, enabled: bool)pub fn is_toggle_mode(&self) -> bool[src]
pub fn is_toggle_mode(&self) -> boolpub fn set_disabled(&mut self, disabled: bool)[src]
pub fn set_disabled(&mut self, disabled: bool)pub fn is_disabled(&self) -> bool[src]
pub fn is_disabled(&self) -> boolpub fn set_action_mode(&mut self, mode: i64)[src]
pub fn set_action_mode(&mut self, mode: i64)pub fn set_enabled_focus_mode(&mut self, mode: i64)[src]
pub fn set_enabled_focus_mode(&mut self, mode: i64)pub fn set_shortcut(&mut self, shortcut: Option<ShortCut>)[src]
pub fn set_shortcut(&mut self, shortcut: Option<ShortCut>)pub fn get_shortcut(&self) -> Option<ShortCut>[src]
pub fn get_shortcut(&self) -> Option<ShortCut>pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Trait Implementations
impl GodotObject for LinkButton[src]
impl GodotObject for LinkButtonfn class_name() -> &'static str[src]
fn class_name() -> &'static strunsafe fn from_sys(obj: *mut godot_object) -> Self[src]
unsafe fn from_sys(obj: *mut godot_object) -> Selfunsafe fn to_sys(&self) -> *mut godot_object[src]
unsafe fn to_sys(&self) -> *mut godot_objectimpl Deref for LinkButton[src]
impl Deref for LinkButtontype Target = BaseButton
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for LinkButton[src]
impl DerefMut for LinkButtonAuto Trait Implementations
impl !Send for LinkButton
impl !Send for LinkButtonimpl !Sync for LinkButton
impl !Sync for LinkButton