Struct gdnative::TouchScreenButton [−][src]
pub struct TouchScreenButton { /* fields omitted */ }core class TouchScreenButton : Node2D (manually managed)
Base class
TouchScreenButton inherits Node2D and all of its methods.
Memory management
Non reference counted objects such as the ones of this type are usually owned by the engine.
In the cases where Rust code owns an object of this type, ownership should be either passed
to the engine or the object must be manually destroyed using TouchScreenButton::free.
Methods
impl TouchScreenButton[src]
impl TouchScreenButtonpub fn as_node_2d(&self) -> Node2D[src]
pub fn as_node_2d(&self) -> Node2DUp-cast.
pub fn new() -> Self[src]
pub fn new() -> SelfConstructor.
Because this type is not reference counted, the lifetime of the returned object
is not automatically managed.
Immediately after creation, the object is owned by the caller, and can be
passed to the engine (in which case the engine will be responsible for
destroying the object) or destroyed manually using TouchScreenButton::free.
pub unsafe fn free(self)[src]
pub unsafe fn free(self)Manually deallocate the object.
pub fn set_texture(&mut self, texture: Option<Texture>)[src]
pub fn set_texture(&mut self, texture: Option<Texture>)pub fn get_texture(&self) -> Option<Texture>[src]
pub fn get_texture(&self) -> Option<Texture>pub fn set_texture_pressed(&mut self, texture_pressed: Option<Texture>)[src]
pub fn set_texture_pressed(&mut self, texture_pressed: Option<Texture>)pub fn get_texture_pressed(&self) -> Option<Texture>[src]
pub fn get_texture_pressed(&self) -> Option<Texture>pub fn set_bitmask(&mut self, bitmask: Option<BitMap>)[src]
pub fn set_bitmask(&mut self, bitmask: Option<BitMap>)pub fn get_bitmask(&self) -> Option<BitMap>[src]
pub fn get_bitmask(&self) -> Option<BitMap>pub fn set_shape(&mut self, shape: Option<Shape2D>)[src]
pub fn set_shape(&mut self, shape: Option<Shape2D>)pub fn get_shape(&self) -> Option<Shape2D>[src]
pub fn get_shape(&self) -> Option<Shape2D>pub fn set_shape_centered(&mut self, bool: bool)[src]
pub fn set_shape_centered(&mut self, bool: bool)pub fn is_shape_centered(&self) -> bool[src]
pub fn is_shape_centered(&self) -> boolpub fn set_shape_visible(&mut self, bool: bool)[src]
pub fn set_shape_visible(&mut self, bool: bool)pub fn is_shape_visible(&self) -> bool[src]
pub fn is_shape_visible(&self) -> boolpub fn set_action(&mut self, action: GodotString)[src]
pub fn set_action(&mut self, action: GodotString)pub fn get_action(&self) -> GodotString[src]
pub fn get_action(&self) -> GodotStringpub fn set_visibility_mode(&mut self, mode: i64)[src]
pub fn set_visibility_mode(&mut self, mode: i64)pub fn set_passby_press(&mut self, enabled: bool)[src]
pub fn set_passby_press(&mut self, enabled: bool)pub fn is_passby_press_enabled(&self) -> bool[src]
pub fn is_passby_press_enabled(&self) -> boolpub fn is_pressed(&self) -> bool[src]
pub fn is_pressed(&self) -> boolpub fn _input(&mut self, arg0: Option<InputEvent>)[src]
pub fn _input(&mut self, arg0: Option<InputEvent>)pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Methods from Deref<Target = Node2D>
pub fn as_canvas_item(&self) -> CanvasItem[src]
pub fn as_canvas_item(&self) -> CanvasItemUp-cast.
pub fn set_position(&mut self, position: Vector2)[src]
pub fn set_position(&mut self, position: Vector2)pub fn set_rotation(&mut self, radians: f64)[src]
pub fn set_rotation(&mut self, radians: f64)pub fn set_rotation_degrees(&mut self, degrees: f64)[src]
pub fn set_rotation_degrees(&mut self, degrees: f64)pub fn set_scale(&mut self, scale: Vector2)[src]
pub fn set_scale(&mut self, scale: Vector2)pub fn get_position(&self) -> Vector2[src]
pub fn get_position(&self) -> Vector2pub fn get_rotation(&self) -> f64[src]
pub fn get_rotation(&self) -> f64pub fn get_rotation_degrees(&self) -> f64[src]
pub fn get_rotation_degrees(&self) -> f64pub fn get_scale(&self) -> Vector2[src]
pub fn get_scale(&self) -> Vector2pub fn rotate(&mut self, radians: f64)[src]
pub fn rotate(&mut self, radians: f64)pub fn move_local_x(&mut self, delta: f64, scaled: bool)[src]
pub fn move_local_x(&mut self, delta: f64, scaled: bool)pub fn move_local_y(&mut self, delta: f64, scaled: bool)[src]
pub fn move_local_y(&mut self, delta: f64, scaled: bool)pub fn translate(&mut self, offset: Vector2)[src]
pub fn translate(&mut self, offset: Vector2)pub fn global_translate(&mut self, offset: Vector2)[src]
pub fn global_translate(&mut self, offset: Vector2)pub fn apply_scale(&mut self, ratio: Vector2)[src]
pub fn apply_scale(&mut self, ratio: Vector2)pub fn set_global_position(&mut self, position: Vector2)[src]
pub fn set_global_position(&mut self, position: Vector2)pub fn get_global_position(&self) -> Vector2[src]
pub fn get_global_position(&self) -> Vector2pub fn set_global_rotation(&mut self, radians: f64)[src]
pub fn set_global_rotation(&mut self, radians: f64)pub fn get_global_rotation(&self) -> f64[src]
pub fn get_global_rotation(&self) -> f64pub fn set_global_rotation_degrees(&mut self, degrees: f64)[src]
pub fn set_global_rotation_degrees(&mut self, degrees: f64)pub fn get_global_rotation_degrees(&self) -> f64[src]
pub fn get_global_rotation_degrees(&self) -> f64pub fn set_global_scale(&mut self, scale: Vector2)[src]
pub fn set_global_scale(&mut self, scale: Vector2)pub fn get_global_scale(&self) -> Vector2[src]
pub fn get_global_scale(&self) -> Vector2pub fn set_transform(&mut self, xform: Transform2D)[src]
pub fn set_transform(&mut self, xform: Transform2D)pub fn set_global_transform(&mut self, xform: Transform2D)[src]
pub fn set_global_transform(&mut self, xform: Transform2D)pub fn look_at(&mut self, point: Vector2)[src]
pub fn look_at(&mut self, point: Vector2)pub fn get_angle_to(&self, point: Vector2) -> f64[src]
pub fn get_angle_to(&self, point: Vector2) -> f64pub fn to_local(&self, global_point: Vector2) -> Vector2[src]
pub fn to_local(&self, global_point: Vector2) -> Vector2pub fn to_global(&self, local_point: Vector2) -> Vector2[src]
pub fn to_global(&self, local_point: Vector2) -> Vector2pub fn set_z_index(&mut self, z_index: i64)[src]
pub fn set_z_index(&mut self, z_index: i64)pub fn get_z_index(&self) -> i64[src]
pub fn get_z_index(&self) -> i64pub fn set_z_as_relative(&mut self, enable: bool)[src]
pub fn set_z_as_relative(&mut self, enable: bool)pub fn is_z_relative(&self) -> bool[src]
pub fn is_z_relative(&self) -> boolpub fn get_relative_transform_to_parent(
&self,
parent: Option<Object>
) -> Transform2D[src]
pub fn get_relative_transform_to_parent(
&self,
parent: Option<Object>
) -> Transform2Dpub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Trait Implementations
impl GodotObject for TouchScreenButton[src]
impl GodotObject for TouchScreenButtonfn class_name() -> &'static str[src]
fn class_name() -> &'static strunsafe fn from_sys(obj: *mut godot_object) -> Self[src]
unsafe fn from_sys(obj: *mut godot_object) -> Selfunsafe fn to_sys(&self) -> *mut godot_object[src]
unsafe fn to_sys(&self) -> *mut godot_objectimpl Deref for TouchScreenButton[src]
impl Deref for TouchScreenButtontype Target = Node2D
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for TouchScreenButton[src]
impl DerefMut for TouchScreenButtonAuto Trait Implementations
impl !Send for TouchScreenButton
impl !Send for TouchScreenButtonimpl !Sync for TouchScreenButton
impl !Sync for TouchScreenButton