Struct gdnative::VehicleBody [−][src]
pub struct VehicleBody { /* fields omitted */ }core class VehicleBody : RigidBody (manually managed)
Base class
VehicleBody inherits RigidBody and all of its methods.
Memory management
Non reference counted objects such as the ones of this type are usually owned by the engine.
In the cases where Rust code owns an object of this type, ownership should be either passed
to the engine or the object must be manually destroyed using VehicleBody::free.
Methods
impl VehicleBody[src]
impl VehicleBodypub fn as_rigid_body(&self) -> RigidBody[src]
pub fn as_rigid_body(&self) -> RigidBodyUp-cast.
pub fn new() -> Self[src]
pub fn new() -> SelfConstructor.
Because this type is not reference counted, the lifetime of the returned object
is not automatically managed.
Immediately after creation, the object is owned by the caller, and can be
passed to the engine (in which case the engine will be responsible for
destroying the object) or destroyed manually using VehicleBody::free.
pub unsafe fn free(self)[src]
pub unsafe fn free(self)Manually deallocate the object.
pub fn set_engine_force(&mut self, engine_force: f64)[src]
pub fn set_engine_force(&mut self, engine_force: f64)pub fn get_engine_force(&self) -> f64[src]
pub fn get_engine_force(&self) -> f64pub fn set_brake(&mut self, brake: f64)[src]
pub fn set_brake(&mut self, brake: f64)pub fn get_brake(&self) -> f64[src]
pub fn get_brake(&self) -> f64pub fn set_steering(&mut self, steering: f64)[src]
pub fn set_steering(&mut self, steering: f64)pub fn get_steering(&self) -> f64[src]
pub fn get_steering(&self) -> f64pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Methods from Deref<Target = RigidBody>
pub fn as_physics_body(&self) -> PhysicsBody[src]
pub fn as_physics_body(&self) -> PhysicsBodyUp-cast.
pub fn _integrate_forces(&mut self, state: Option<PhysicsDirectBodyState>)[src]
pub fn _integrate_forces(&mut self, state: Option<PhysicsDirectBodyState>)pub fn set_mode(&mut self, mode: i64)[src]
pub fn set_mode(&mut self, mode: i64)pub fn set_mass(&mut self, mass: f64)[src]
pub fn set_mass(&mut self, mass: f64)pub fn get_mass(&self) -> f64[src]
pub fn get_mass(&self) -> f64pub fn set_weight(&mut self, weight: f64)[src]
pub fn set_weight(&mut self, weight: f64)pub fn get_weight(&self) -> f64[src]
pub fn get_weight(&self) -> f64pub fn set_friction(&mut self, friction: f64)[src]
pub fn set_friction(&mut self, friction: f64)pub fn get_friction(&self) -> f64[src]
pub fn get_friction(&self) -> f64pub fn set_bounce(&mut self, bounce: f64)[src]
pub fn set_bounce(&mut self, bounce: f64)pub fn get_bounce(&self) -> f64[src]
pub fn get_bounce(&self) -> f64pub fn set_linear_velocity(&mut self, linear_velocity: Vector3)[src]
pub fn set_linear_velocity(&mut self, linear_velocity: Vector3)pub fn get_linear_velocity(&self) -> Vector3[src]
pub fn get_linear_velocity(&self) -> Vector3pub fn set_angular_velocity(&mut self, angular_velocity: Vector3)[src]
pub fn set_angular_velocity(&mut self, angular_velocity: Vector3)pub fn get_angular_velocity(&self) -> Vector3[src]
pub fn get_angular_velocity(&self) -> Vector3pub fn set_gravity_scale(&mut self, gravity_scale: f64)[src]
pub fn set_gravity_scale(&mut self, gravity_scale: f64)pub fn get_gravity_scale(&self) -> f64[src]
pub fn get_gravity_scale(&self) -> f64pub fn set_linear_damp(&mut self, linear_damp: f64)[src]
pub fn set_linear_damp(&mut self, linear_damp: f64)pub fn get_linear_damp(&self) -> f64[src]
pub fn get_linear_damp(&self) -> f64pub fn set_angular_damp(&mut self, angular_damp: f64)[src]
pub fn set_angular_damp(&mut self, angular_damp: f64)pub fn get_angular_damp(&self) -> f64[src]
pub fn get_angular_damp(&self) -> f64pub fn set_max_contacts_reported(&mut self, amount: i64)[src]
pub fn set_max_contacts_reported(&mut self, amount: i64)pub fn get_max_contacts_reported(&self) -> i64[src]
pub fn get_max_contacts_reported(&self) -> i64pub fn set_use_custom_integrator(&mut self, enable: bool)[src]
pub fn set_use_custom_integrator(&mut self, enable: bool)pub fn is_using_custom_integrator(&mut self) -> bool[src]
pub fn is_using_custom_integrator(&mut self) -> boolpub fn set_contact_monitor(&mut self, enabled: bool)[src]
pub fn set_contact_monitor(&mut self, enabled: bool)pub fn is_contact_monitor_enabled(&self) -> bool[src]
pub fn is_contact_monitor_enabled(&self) -> boolpub fn set_use_continuous_collision_detection(&mut self, enable: bool)[src]
pub fn set_use_continuous_collision_detection(&mut self, enable: bool)pub fn is_using_continuous_collision_detection(&self) -> bool[src]
pub fn is_using_continuous_collision_detection(&self) -> boolpub fn set_axis_velocity(&mut self, axis_velocity: Vector3)[src]
pub fn set_axis_velocity(&mut self, axis_velocity: Vector3)pub fn apply_impulse(&mut self, position: Vector3, impulse: Vector3)[src]
pub fn apply_impulse(&mut self, position: Vector3, impulse: Vector3)pub fn set_sleeping(&mut self, sleeping: bool)[src]
pub fn set_sleeping(&mut self, sleeping: bool)pub fn is_sleeping(&self) -> bool[src]
pub fn is_sleeping(&self) -> boolpub fn set_can_sleep(&mut self, able_to_sleep: bool)[src]
pub fn set_can_sleep(&mut self, able_to_sleep: bool)pub fn is_able_to_sleep(&self) -> bool[src]
pub fn is_able_to_sleep(&self) -> boolpub fn _direct_state_changed(&mut self, arg0: Option<Object>)[src]
pub fn _direct_state_changed(&mut self, arg0: Option<Object>)pub fn _body_enter_tree(&mut self, arg0: i64)[src]
pub fn _body_enter_tree(&mut self, arg0: i64)pub fn _body_exit_tree(&mut self, arg0: i64)[src]
pub fn _body_exit_tree(&mut self, arg0: i64)pub fn set_axis_lock(&mut self, axis: i64, lock: bool)[src]
pub fn set_axis_lock(&mut self, axis: i64, lock: bool)pub fn get_axis_lock(&self, axis: i64) -> bool[src]
pub fn get_axis_lock(&self, axis: i64) -> boolpub fn get_colliding_bodies(&self) -> VariantArray[src]
pub fn get_colliding_bodies(&self) -> VariantArraypub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Trait Implementations
impl GodotObject for VehicleBody[src]
impl GodotObject for VehicleBodyfn class_name() -> &'static str[src]
fn class_name() -> &'static strunsafe fn from_sys(obj: *mut godot_object) -> Self[src]
unsafe fn from_sys(obj: *mut godot_object) -> Selfunsafe fn to_sys(&self) -> *mut godot_object[src]
unsafe fn to_sys(&self) -> *mut godot_objectimpl Deref for VehicleBody[src]
impl Deref for VehicleBodytype Target = RigidBody
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for VehicleBody[src]
impl DerefMut for VehicleBodyAuto Trait Implementations
impl !Send for VehicleBody
impl !Send for VehicleBodyimpl !Sync for VehicleBody
impl !Sync for VehicleBody