Struct gdnative::VideoPlayer [−][src]
pub struct VideoPlayer { /* fields omitted */ }core class VideoPlayer : Control (manually managed)
Base class
VideoPlayer inherits Control and all of its methods.
Memory management
Non reference counted objects such as the ones of this type are usually owned by the engine.
In the cases where Rust code owns an object of this type, ownership should be either passed
to the engine or the object must be manually destroyed using VideoPlayer::free.
Methods
impl VideoPlayer[src]
impl VideoPlayerpub fn as_control(&self) -> Control[src]
pub fn as_control(&self) -> ControlUp-cast.
pub fn new() -> Self[src]
pub fn new() -> SelfConstructor.
Because this type is not reference counted, the lifetime of the returned object
is not automatically managed.
Immediately after creation, the object is owned by the caller, and can be
passed to the engine (in which case the engine will be responsible for
destroying the object) or destroyed manually using VideoPlayer::free.
pub unsafe fn free(self)[src]
pub unsafe fn free(self)Manually deallocate the object.
pub fn set_stream(&mut self, stream: Option<VideoStream>)[src]
pub fn set_stream(&mut self, stream: Option<VideoStream>)pub fn get_stream(&self) -> Option<VideoStream>[src]
pub fn get_stream(&self) -> Option<VideoStream>pub fn play(&mut self)[src]
pub fn play(&mut self)pub fn stop(&mut self)[src]
pub fn stop(&mut self)pub fn is_playing(&self) -> bool[src]
pub fn is_playing(&self) -> boolpub fn set_paused(&mut self, paused: bool)[src]
pub fn set_paused(&mut self, paused: bool)pub fn is_paused(&self) -> bool[src]
pub fn is_paused(&self) -> boolpub fn set_volume(&mut self, volume: f64)[src]
pub fn set_volume(&mut self, volume: f64)pub fn get_volume(&self) -> f64[src]
pub fn get_volume(&self) -> f64pub fn set_volume_db(&mut self, db: f64)[src]
pub fn set_volume_db(&mut self, db: f64)pub fn get_volume_db(&self) -> f64[src]
pub fn get_volume_db(&self) -> f64pub fn set_audio_track(&mut self, track: i64)[src]
pub fn set_audio_track(&mut self, track: i64)pub fn get_audio_track(&self) -> i64[src]
pub fn get_audio_track(&self) -> i64pub fn get_stream_name(&self) -> GodotString[src]
pub fn get_stream_name(&self) -> GodotStringpub fn set_stream_position(&mut self, position: f64)[src]
pub fn set_stream_position(&mut self, position: f64)pub fn get_stream_position(&self) -> f64[src]
pub fn get_stream_position(&self) -> f64pub fn set_autoplay(&mut self, enabled: bool)[src]
pub fn set_autoplay(&mut self, enabled: bool)pub fn has_autoplay(&self) -> bool[src]
pub fn has_autoplay(&self) -> boolpub fn set_expand(&mut self, enable: bool)[src]
pub fn set_expand(&mut self, enable: bool)pub fn has_expand(&self) -> bool[src]
pub fn has_expand(&self) -> boolpub fn set_buffering_msec(&mut self, msec: i64)[src]
pub fn set_buffering_msec(&mut self, msec: i64)pub fn get_buffering_msec(&self) -> i64[src]
pub fn get_buffering_msec(&self) -> i64pub fn set_bus(&mut self, bus: GodotString)[src]
pub fn set_bus(&mut self, bus: GodotString)pub fn get_bus(&self) -> GodotString[src]
pub fn get_bus(&self) -> GodotStringpub fn get_video_texture(&mut self) -> Option<Texture>[src]
pub fn get_video_texture(&mut self) -> Option<Texture>pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Methods from Deref<Target = Control>
pub fn as_canvas_item(&self) -> CanvasItem[src]
pub fn as_canvas_item(&self) -> CanvasItemUp-cast.
pub fn _gui_input(&mut self, event: Option<InputEvent>)[src]
pub fn _gui_input(&mut self, event: Option<InputEvent>)pub fn _get_minimum_size(&mut self) -> Vector2[src]
pub fn _get_minimum_size(&mut self) -> Vector2pub fn get_drag_data(&mut self, position: Vector2) -> Option<Object>[src]
pub fn get_drag_data(&mut self, position: Vector2) -> Option<Object>pub fn can_drop_data(&mut self, position: Vector2, data: Variant) -> bool[src]
pub fn can_drop_data(&mut self, position: Vector2, data: Variant) -> boolpub fn drop_data(&mut self, position: Vector2, data: Variant)[src]
pub fn drop_data(&mut self, position: Vector2, data: Variant)pub fn has_point(&mut self, point: Vector2) -> bool[src]
pub fn has_point(&mut self, point: Vector2) -> boolpub fn _size_changed(&mut self)[src]
pub fn _size_changed(&mut self)pub fn _update_minimum_size(&mut self)[src]
pub fn _update_minimum_size(&mut self)pub fn accept_event(&mut self)[src]
pub fn accept_event(&mut self)pub fn get_minimum_size(&self) -> Vector2[src]
pub fn get_minimum_size(&self) -> Vector2pub fn get_combined_minimum_size(&self) -> Vector2[src]
pub fn get_combined_minimum_size(&self) -> Vector2pub fn set_anchors_preset(&mut self, preset: i64, keep_margin: bool)[src]
pub fn set_anchors_preset(&mut self, preset: i64, keep_margin: bool)pub fn set_margins_preset(&mut self, preset: i64, resize_mode: i64, margin: i64)[src]
pub fn set_margins_preset(&mut self, preset: i64, resize_mode: i64, margin: i64)pub fn set_anchors_and_margins_preset(
&mut self,
preset: i64,
resize_mode: i64,
margin: i64
)[src]
pub fn set_anchors_and_margins_preset(
&mut self,
preset: i64,
resize_mode: i64,
margin: i64
)pub fn set_anchor(
&mut self,
margin: i64,
anchor: f64,
keep_margin: bool,
push_opposite_anchor: bool
)[src]
pub fn set_anchor(
&mut self,
margin: i64,
anchor: f64,
keep_margin: bool,
push_opposite_anchor: bool
)pub fn _set_anchor(&mut self, margin: i64, anchor: f64)[src]
pub fn _set_anchor(&mut self, margin: i64, anchor: f64)pub fn get_anchor(&self, margin: i64) -> f64[src]
pub fn get_anchor(&self, margin: i64) -> f64pub fn set_margin(&mut self, margin: i64, offset: f64)[src]
pub fn set_margin(&mut self, margin: i64, offset: f64)pub fn set_anchor_and_margin(
&mut self,
margin: i64,
anchor: f64,
offset: f64,
push_opposite_anchor: bool
)[src]
pub fn set_anchor_and_margin(
&mut self,
margin: i64,
anchor: f64,
offset: f64,
push_opposite_anchor: bool
)pub fn set_begin(&mut self, position: Vector2)[src]
pub fn set_begin(&mut self, position: Vector2)pub fn set_end(&mut self, position: Vector2)[src]
pub fn set_end(&mut self, position: Vector2)pub fn set_position(&mut self, position: Vector2)[src]
pub fn set_position(&mut self, position: Vector2)pub fn set_size(&mut self, size: Vector2)[src]
pub fn set_size(&mut self, size: Vector2)pub fn set_custom_minimum_size(&mut self, size: Vector2)[src]
pub fn set_custom_minimum_size(&mut self, size: Vector2)pub fn set_global_position(&mut self, position: Vector2)[src]
pub fn set_global_position(&mut self, position: Vector2)pub fn set_rotation(&mut self, radians: f64)[src]
pub fn set_rotation(&mut self, radians: f64)pub fn set_rotation_degrees(&mut self, degrees: f64)[src]
pub fn set_rotation_degrees(&mut self, degrees: f64)pub fn set_scale(&mut self, scale: Vector2)[src]
pub fn set_scale(&mut self, scale: Vector2)pub fn set_pivot_offset(&mut self, pivot_offset: Vector2)[src]
pub fn set_pivot_offset(&mut self, pivot_offset: Vector2)pub fn get_margin(&self, margin: i64) -> f64[src]
pub fn get_margin(&self, margin: i64) -> f64pub fn get_begin(&self) -> Vector2[src]
pub fn get_begin(&self) -> Vector2pub fn get_end(&self) -> Vector2[src]
pub fn get_end(&self) -> Vector2pub fn get_position(&self) -> Vector2[src]
pub fn get_position(&self) -> Vector2pub fn get_size(&self) -> Vector2[src]
pub fn get_size(&self) -> Vector2pub fn get_rotation(&self) -> f64[src]
pub fn get_rotation(&self) -> f64pub fn get_rotation_degrees(&self) -> f64[src]
pub fn get_rotation_degrees(&self) -> f64pub fn get_scale(&self) -> Vector2[src]
pub fn get_scale(&self) -> Vector2pub fn get_pivot_offset(&self) -> Vector2[src]
pub fn get_pivot_offset(&self) -> Vector2pub fn get_custom_minimum_size(&self) -> Vector2[src]
pub fn get_custom_minimum_size(&self) -> Vector2pub fn get_parent_area_size(&self) -> Vector2[src]
pub fn get_parent_area_size(&self) -> Vector2pub fn get_global_position(&self) -> Vector2[src]
pub fn get_global_position(&self) -> Vector2pub fn get_rect(&self) -> Rect2[src]
pub fn get_rect(&self) -> Rect2pub fn get_global_rect(&self) -> Rect2[src]
pub fn get_global_rect(&self) -> Rect2pub fn show_modal(&mut self, exclusive: bool)[src]
pub fn show_modal(&mut self, exclusive: bool)pub fn set_focus_mode(&mut self, mode: i64)[src]
pub fn set_focus_mode(&mut self, mode: i64)pub fn has_focus(&self) -> bool[src]
pub fn has_focus(&self) -> boolpub fn grab_focus(&mut self)[src]
pub fn grab_focus(&mut self)pub fn release_focus(&mut self)[src]
pub fn release_focus(&mut self)pub fn get_focus_owner(&self) -> Option<Control>[src]
pub fn get_focus_owner(&self) -> Option<Control>pub fn set_h_size_flags(&mut self, flags: i64)[src]
pub fn set_h_size_flags(&mut self, flags: i64)pub fn get_h_size_flags(&self) -> i64[src]
pub fn get_h_size_flags(&self) -> i64pub fn set_stretch_ratio(&mut self, ratio: f64)[src]
pub fn set_stretch_ratio(&mut self, ratio: f64)pub fn get_stretch_ratio(&self) -> f64[src]
pub fn get_stretch_ratio(&self) -> f64pub fn set_v_size_flags(&mut self, flags: i64)[src]
pub fn set_v_size_flags(&mut self, flags: i64)pub fn get_v_size_flags(&self) -> i64[src]
pub fn get_v_size_flags(&self) -> i64pub fn set_theme(&mut self, theme: Option<Theme>)[src]
pub fn set_theme(&mut self, theme: Option<Theme>)pub fn get_theme(&self) -> Option<Theme>[src]
pub fn get_theme(&self) -> Option<Theme>pub fn add_icon_override(&mut self, name: GodotString, texture: Option<Texture>)[src]
pub fn add_icon_override(&mut self, name: GodotString, texture: Option<Texture>)pub fn add_shader_override(&mut self, name: GodotString, shader: Option<Shader>)[src]
pub fn add_shader_override(&mut self, name: GodotString, shader: Option<Shader>)pub fn add_stylebox_override(
&mut self,
name: GodotString,
stylebox: Option<StyleBox>
)[src]
pub fn add_stylebox_override(
&mut self,
name: GodotString,
stylebox: Option<StyleBox>
)pub fn add_font_override(&mut self, name: GodotString, font: Option<Font>)[src]
pub fn add_font_override(&mut self, name: GodotString, font: Option<Font>)pub fn add_color_override(&mut self, name: GodotString, color: Color)[src]
pub fn add_color_override(&mut self, name: GodotString, color: Color)pub fn add_constant_override(&mut self, name: GodotString, constant: i64)[src]
pub fn add_constant_override(&mut self, name: GodotString, constant: i64)pub fn get_icon(&self, name: GodotString, _type: GodotString) -> Option<Texture>[src]
pub fn get_icon(&self, name: GodotString, _type: GodotString) -> Option<Texture>pub fn get_stylebox(
&self,
name: GodotString,
_type: GodotString
) -> Option<StyleBox>[src]
pub fn get_stylebox(
&self,
name: GodotString,
_type: GodotString
) -> Option<StyleBox>pub fn get_font(&self, name: GodotString, _type: GodotString) -> Option<Font>[src]
pub fn get_font(&self, name: GodotString, _type: GodotString) -> Option<Font>pub fn get_color(&self, name: GodotString, _type: GodotString) -> Color[src]
pub fn get_color(&self, name: GodotString, _type: GodotString) -> Colorpub fn get_constant(&self, name: GodotString, _type: GodotString) -> i64[src]
pub fn get_constant(&self, name: GodotString, _type: GodotString) -> i64pub fn has_icon_override(&self, name: GodotString) -> bool[src]
pub fn has_icon_override(&self, name: GodotString) -> boolpub fn has_shader_override(&self, name: GodotString) -> bool[src]
pub fn has_shader_override(&self, name: GodotString) -> boolpub fn has_stylebox_override(&self, name: GodotString) -> bool[src]
pub fn has_stylebox_override(&self, name: GodotString) -> boolpub fn has_font_override(&self, name: GodotString) -> bool[src]
pub fn has_font_override(&self, name: GodotString) -> boolpub fn has_color_override(&self, name: GodotString) -> bool[src]
pub fn has_color_override(&self, name: GodotString) -> boolpub fn has_constant_override(&self, name: GodotString) -> bool[src]
pub fn has_constant_override(&self, name: GodotString) -> boolpub fn has_icon(&self, name: GodotString, _type: GodotString) -> bool[src]
pub fn has_icon(&self, name: GodotString, _type: GodotString) -> boolpub fn has_stylebox(&self, name: GodotString, _type: GodotString) -> bool[src]
pub fn has_stylebox(&self, name: GodotString, _type: GodotString) -> boolpub fn has_font(&self, name: GodotString, _type: GodotString) -> bool[src]
pub fn has_font(&self, name: GodotString, _type: GodotString) -> boolpub fn has_color(&self, name: GodotString, _type: GodotString) -> bool[src]
pub fn has_color(&self, name: GodotString, _type: GodotString) -> boolpub fn has_constant(&self, name: GodotString, _type: GodotString) -> bool[src]
pub fn has_constant(&self, name: GodotString, _type: GodotString) -> boolpub fn get_parent_control(&self) -> Option<Control>[src]
pub fn get_parent_control(&self) -> Option<Control>pub fn set_h_grow_direction(&mut self, direction: i64)[src]
pub fn set_h_grow_direction(&mut self, direction: i64)pub fn set_v_grow_direction(&mut self, direction: i64)[src]
pub fn set_v_grow_direction(&mut self, direction: i64)pub fn set_tooltip(&mut self, tooltip: GodotString)[src]
pub fn set_tooltip(&mut self, tooltip: GodotString)pub fn get_tooltip(&self, at_position: Vector2) -> GodotString[src]
pub fn get_tooltip(&self, at_position: Vector2) -> GodotStringpub fn _get_tooltip(&self) -> GodotString[src]
pub fn _get_tooltip(&self) -> GodotStringpub fn set_default_cursor_shape(&mut self, shape: i64)[src]
pub fn set_default_cursor_shape(&mut self, shape: i64)pub fn set_focus_neighbour(&mut self, margin: i64, neighbour: NodePath)[src]
pub fn set_focus_neighbour(&mut self, margin: i64, neighbour: NodePath)pub fn get_focus_neighbour(&self, margin: i64) -> NodePath[src]
pub fn get_focus_neighbour(&self, margin: i64) -> NodePathpub fn set_focus_next(&mut self, next: NodePath)[src]
pub fn set_focus_next(&mut self, next: NodePath)pub fn get_focus_next(&self) -> NodePath[src]
pub fn get_focus_next(&self) -> NodePathpub fn set_focus_previous(&mut self, previous: NodePath)[src]
pub fn set_focus_previous(&mut self, previous: NodePath)pub fn get_focus_previous(&self) -> NodePath[src]
pub fn get_focus_previous(&self) -> NodePathpub fn force_drag(&mut self, data: Variant, preview: Option<Object>)[src]
pub fn force_drag(&mut self, data: Variant, preview: Option<Object>)pub fn set_mouse_filter(&mut self, filter: i64)[src]
pub fn set_mouse_filter(&mut self, filter: i64)pub fn set_clip_contents(&mut self, enable: bool)[src]
pub fn set_clip_contents(&mut self, enable: bool)pub fn is_clipping_contents(&mut self) -> bool[src]
pub fn is_clipping_contents(&mut self) -> boolpub fn grab_click_focus(&mut self)[src]
pub fn grab_click_focus(&mut self)pub fn set_drag_forwarding(&mut self, target: Option<Object>)[src]
pub fn set_drag_forwarding(&mut self, target: Option<Object>)pub fn set_drag_preview(&mut self, control: Option<Object>)[src]
pub fn set_drag_preview(&mut self, control: Option<Object>)pub fn warp_mouse(&mut self, to_position: Vector2)[src]
pub fn warp_mouse(&mut self, to_position: Vector2)pub fn minimum_size_changed(&mut self)[src]
pub fn minimum_size_changed(&mut self)pub fn _theme_changed(&mut self)[src]
pub fn _theme_changed(&mut self)pub fn _font_changed(&mut self)[src]
pub fn _font_changed(&mut self)pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Trait Implementations
impl GodotObject for VideoPlayer[src]
impl GodotObject for VideoPlayerfn class_name() -> &'static str[src]
fn class_name() -> &'static strunsafe fn from_sys(obj: *mut godot_object) -> Self[src]
unsafe fn from_sys(obj: *mut godot_object) -> Selfunsafe fn to_sys(&self) -> *mut godot_object[src]
unsafe fn to_sys(&self) -> *mut godot_objectimpl Deref for VideoPlayer[src]
impl Deref for VideoPlayertype Target = Control
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for VideoPlayer[src]
impl DerefMut for VideoPlayerAuto Trait Implementations
impl !Send for VideoPlayer
impl !Send for VideoPlayerimpl !Sync for VideoPlayer
impl !Sync for VideoPlayer