Struct gdnative::VisibilityEnabler2D [−][src]
pub struct VisibilityEnabler2D { /* fields omitted */ }core class VisibilityEnabler2D : VisibilityNotifier2D (manually managed)
Base class
VisibilityEnabler2D inherits VisibilityNotifier2D and all of its methods.
Memory management
Non reference counted objects such as the ones of this type are usually owned by the engine.
In the cases where Rust code owns an object of this type, ownership should be either passed
to the engine or the object must be manually destroyed using VisibilityEnabler2D::free.
Methods
impl VisibilityEnabler2D[src]
impl VisibilityEnabler2Dpub fn as_visibility_notifier_2d(&self) -> VisibilityNotifier2D[src]
pub fn as_visibility_notifier_2d(&self) -> VisibilityNotifier2DUp-cast.
pub fn new() -> Self[src]
pub fn new() -> SelfConstructor.
Because this type is not reference counted, the lifetime of the returned object
is not automatically managed.
Immediately after creation, the object is owned by the caller, and can be
passed to the engine (in which case the engine will be responsible for
destroying the object) or destroyed manually using VisibilityEnabler2D::free.
pub unsafe fn free(self)[src]
pub unsafe fn free(self)Manually deallocate the object.
pub fn set_enabler(&mut self, enabler: i64, enabled: bool)[src]
pub fn set_enabler(&mut self, enabler: i64, enabled: bool)pub fn is_enabler_enabled(&self, enabler: i64) -> bool[src]
pub fn is_enabler_enabled(&self, enabler: i64) -> boolpub fn _node_removed(&mut self, arg0: Option<Object>)[src]
pub fn _node_removed(&mut self, arg0: Option<Object>)pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Methods from Deref<Target = VisibilityNotifier2D>
pub fn as_node_2d(&self) -> Node2D[src]
pub fn as_node_2d(&self) -> Node2DUp-cast.
pub fn set_rect(&mut self, rect: Rect2)[src]
pub fn set_rect(&mut self, rect: Rect2)pub fn get_rect(&self) -> Rect2[src]
pub fn get_rect(&self) -> Rect2pub fn is_on_screen(&self) -> bool[src]
pub fn is_on_screen(&self) -> boolpub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Trait Implementations
impl GodotObject for VisibilityEnabler2D[src]
impl GodotObject for VisibilityEnabler2Dfn class_name() -> &'static str[src]
fn class_name() -> &'static strunsafe fn from_sys(obj: *mut godot_object) -> Self[src]
unsafe fn from_sys(obj: *mut godot_object) -> Selfunsafe fn to_sys(&self) -> *mut godot_object[src]
unsafe fn to_sys(&self) -> *mut godot_objectimpl Deref for VisibilityEnabler2D[src]
impl Deref for VisibilityEnabler2Dtype Target = VisibilityNotifier2D
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for VisibilityEnabler2D[src]
impl DerefMut for VisibilityEnabler2DAuto Trait Implementations
impl !Send for VisibilityEnabler2D
impl !Send for VisibilityEnabler2Dimpl !Sync for VisibilityEnabler2D
impl !Sync for VisibilityEnabler2D