Struct gdnative::WindowDialog [−][src]
pub struct WindowDialog { /* fields omitted */ }core class WindowDialog : Popup (manually managed)
Base class
WindowDialog inherits Popup and all of its methods.
Memory management
Non reference counted objects such as the ones of this type are usually owned by the engine.
In the cases where Rust code owns an object of this type, ownership should be either passed
to the engine or the object must be manually destroyed using WindowDialog::free.
Methods
impl WindowDialog[src]
impl WindowDialogpub fn as_popup(&self) -> Popup[src]
pub fn as_popup(&self) -> PopupUp-cast.
pub fn new() -> Self[src]
pub fn new() -> SelfConstructor.
Because this type is not reference counted, the lifetime of the returned object
is not automatically managed.
Immediately after creation, the object is owned by the caller, and can be
passed to the engine (in which case the engine will be responsible for
destroying the object) or destroyed manually using WindowDialog::free.
pub unsafe fn free(self)[src]
pub unsafe fn free(self)Manually deallocate the object.
pub fn _gui_input(&mut self, arg0: Option<InputEvent>)[src]
pub fn _gui_input(&mut self, arg0: Option<InputEvent>)pub fn set_title(&mut self, title: GodotString)[src]
pub fn set_title(&mut self, title: GodotString)pub fn get_title(&self) -> GodotString[src]
pub fn get_title(&self) -> GodotStringpub fn set_resizable(&mut self, resizable: bool)[src]
pub fn set_resizable(&mut self, resizable: bool)pub fn get_resizable(&self) -> bool[src]
pub fn get_resizable(&self) -> boolpub fn _closed(&mut self)[src]
pub fn _closed(&mut self)pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Methods from Deref<Target = Popup>
pub fn as_control(&self) -> Control[src]
pub fn as_control(&self) -> ControlUp-cast.
pub fn popup_centered(&mut self, size: Vector2)[src]
pub fn popup_centered(&mut self, size: Vector2)pub fn popup_centered_ratio(&mut self, ratio: f64)[src]
pub fn popup_centered_ratio(&mut self, ratio: f64)pub fn popup_centered_minsize(&mut self, minsize: Vector2)[src]
pub fn popup_centered_minsize(&mut self, minsize: Vector2)pub fn popup(&mut self, bounds: Rect2)[src]
pub fn popup(&mut self, bounds: Rect2)pub fn set_exclusive(&mut self, enable: bool)[src]
pub fn set_exclusive(&mut self, enable: bool)pub fn is_exclusive(&self) -> bool[src]
pub fn is_exclusive(&self) -> boolpub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Trait Implementations
impl GodotObject for WindowDialog[src]
impl GodotObject for WindowDialogfn class_name() -> &'static str[src]
fn class_name() -> &'static strunsafe fn from_sys(obj: *mut godot_object) -> Self[src]
unsafe fn from_sys(obj: *mut godot_object) -> Selfunsafe fn to_sys(&self) -> *mut godot_object[src]
unsafe fn to_sys(&self) -> *mut godot_objectimpl Deref for WindowDialog[src]
impl Deref for WindowDialogtype Target = Popup
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for WindowDialog[src]
impl DerefMut for WindowDialogAuto Trait Implementations
impl !Send for WindowDialog
impl !Send for WindowDialogimpl !Sync for WindowDialog
impl !Sync for WindowDialog