User-data attributes from export::user_data module.
Structs
- Aether
- Special user-data wrapper intended for zero-sized types, that does not perform any
allocation or synchronization at runtime. Does not implement
MapMut. - ArcData
- User-data wrapper encapsulating a
Arc<T>. Does not implementMapMut. - Local
Cell Data - User-data wrapper analogous to a
Arc<RefCell<T>>, that is restricted to the thread where it was originally created. The destructor ofTis not guaranteed to be run if this is actually shared across multiple threads. - Mutex
Data - User-data wrapper encapsulating a
Arc<Mutex<T>>. - RwLock
Data - User-data wrapper encapsulating a
Arc<RwLock<T>>.